Learn R Programming

denovolyzeR (version 0.2.0)

PermuteMultiHits: Permutes x variants across a genelist, and counts genes with multiple hits

Description

An internal function called by denovolyzeMultiHits

Usage

PermuteMultiHits(x, y, nperms = 100, class = "lof", geneId = "geneName", includeGenes = "all", probTable = pDNM)

Arguments

x
Total number of de novo variants observed in dataset
y
Number of genes with >1 de novo variant (of class "class") in the population
nperms
Number permutations
class
In c("lof","mis","syn","prot")
geneId
Gene identifier used. One of "hgncID", "hgncSymbol", "enstID", "ensgID" or "geneName" (default, equals ensembl "external_gene_name")
includeGenes
Genes to include in analysis. "all" or a vector of gene names.
probTable
Probability table. A user-defined table of probabilities can be provided here, to replace the probability table included in the package.

Value

Returns a named vector of 5 values

See Also

denovolyzeMultiHits