Arguments
x
Total number of de novo variants observed in dataset
y
Number of genes with >1 de novo variant (of class "class") in the population
nperms
Number permutations
class
In c("lof","mis","syn","prot")
geneId
Gene identifier used. One of "hgncID", "hgncSymbol",
"enstID", "ensgID" or "geneName" (default, equals ensembl "external_gene_name")
includeGenes
Genes to include in analysis. "all" or a vector of gene
names.
probTable
Probability table. A user-defined table of probabilities can
be provided here, to replace the probability table included in the package.